<?php
session_start();

// Перевірка авторизації
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Завантаження поточних налаштувань
$config = json_decode(file_get_contents('config.json'), true);

// Оновлення налаштувань
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $config['base_url'] = $_POST['base_url'];
    $config['db_host'] = $_POST['db_host'];
    $config['db_user'] = $_POST['db_user'];
    $config['db_password'] = $_POST['db_password'];
    $config['db_name'] = $_POST['db_name'];
    $config['login'] = $_POST['login'];
    $config['password'] = $_POST['password'];

    // Збереження змін у файлі без екранування слешів
    file_put_contents('config.json', json_encode($config, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES));
}
?>

<!DOCTYPE html>
<html lang="uk">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Налаштування</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f2f2f2;
            margin: 0;
            padding: 20px;
        }
        .container {
            max-width: 600px;
            margin: 0 auto;
            background-color: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        .input-group {
            margin-bottom: 15px;
        }
        .input-group label {
            display: block;
            margin-bottom: 5px;
        }
        .input-group input {
            width: 100%;
            padding: 8px;
            box-sizing: border-box;
        }
        .button {
            width: 100%;
            padding: 10px;
            background-color: #4CAF50;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
        .button:hover {
            background-color: #45a049;
        }
    </style>
</head>
<body>
    <div class="container">
        <h2>Налаштування</h2>
        
        <form method="POST">
            <div class="input-group">
                <label for="base_url">Base URL:</label>
                <input type="text" id="base_url" name="base_url" value="<?= htmlspecialchars($config['base_url'], ENT_QUOTES); ?>" required>
            </div>

            <h3>База даних</h3>
            <div class="input-group">
                <label for="db_host">DB Host:</label>
                <input type="text" id="db_host" name="db_host" value="<?= htmlspecialchars($config['db_host'], ENT_QUOTES); ?>" required>
            </div>
            <div class="input-group">
                <label for="db_user">DB User:</label>
                <input type="text" id="db_user" name="db_user" value="<?= htmlspecialchars($config['db_user'], ENT_QUOTES); ?>" required>
            </div>
            <div class="input-group">
                <label for="db_password">DB Password:</label>
                <input type="password" id="db_password" name="db_password" value="<?= htmlspecialchars($config['db_password'], ENT_QUOTES); ?>" required>
            </div>
            <div class="input-group">
                <label for="db_name">DB Name:</label>
                <input type="text" id="db_name" name="db_name" value="<?= htmlspecialchars($config['db_name'], ENT_QUOTES); ?>" required>
            </div>

            <h3>Користувач адмін</h3>
            <div class="input-group">
                <label for="login">Ім'я користувача:</label>
                <input type="text" id="login" name="login" value="<?= htmlspecialchars($config['login'], ENT_QUOTES); ?>" required>
            </div>
            <div class="input-group">
                <label for="password">Пароль:</label>
                <input type="password" id="password" name="password" value="<?= htmlspecialchars($config['password'], ENT_QUOTES); ?>" required>
            </div>

            <button type="submit" class="button">Зберегти</button>
        </form>
    </div>
</body>
</html>
