<?php
// Параметри з'єднання з базою даних
$config = json_decode(file_get_contents('config.json'), true);
$servername = isset($config['db_host']) ? $config['db_host'] : 'localhost';
$username = isset($config['db_user']) ? $config['db_user'] : 'root';
$password = isset($config['db_password']) ? $config['db_password'] : '';
$dbname = isset($config['db_name']) ? $config['db_name'] : 'core';

// Отримання даних з GET
$providedLogin = isset($_GET['login']) ? $_GET['login'] : '';
$providedPassword = isset($_GET['password']) ? $_GET['password'] : '';

// Перевірка логіну та пароля
if ($providedLogin !== $config['login'] || $providedPassword !== $config['password']) {
    die("Invalid login or password.");
}

// Створення з'єднання з базою даних
$conn = new mysqli($servername, $username, $password, $dbname);

// Перевірка з'єднання
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Перевірка даних для додавання товару
$itemName = isset($_POST['name']) ? $_POST['name'] : '';
$itemPrice = isset($_POST['price']) ? $_POST['price'] : 0;

if (empty($itemName) || !is_numeric($itemPrice) || $itemPrice <= 0) {
    die("Невірні дані для товару.");
}

// Генерація унікального ID для нового товару
function generateUniqueItemId($conn) {
    do {
        $itemId = rand(1000, 9999);
        $sql = "SELECT COUNT(*) AS count FROM items WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $itemId);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        $stmt->close();
    } while ($row['count'] > 0);

    return $itemId;
}

$newItemId = generateUniqueItemId($conn);

// Додавання нового товару до бази даних
$sql = "INSERT INTO items (id, name, price) VALUES (?, ?, ?)";
$stmt = $conn->prepare($sql);
$stmt->bind_param("isd", $newItemId, $itemName, $itemPrice);
$stmt->execute();

?>

<!DOCTYPE html>
<html lang="uk">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Додавання товару</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f2f2f2;
            margin: 0;
            padding: 20px;
        }
        .container {
            max-width: 600px;
            margin: 0 auto;
            background-color: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        .message {
            font-size: 18px;
            margin-bottom: 20px;
        }
        .button-copy {
            display: inline-block;
            padding: 10px 20px;
            font-size: 16px;
            background-color: #4CAF50;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            margin-right: 10px;
        }
        .button-copy:hover {
            background-color: #45a049;
        }
        .button-back {
            display: inline-block;
            padding: 10px 20px;
            font-size: 16px;
            background-color: #007BFF;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
        .button-back:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>
    <div class="container">
        <?php if ($stmt->affected_rows > 0): ?>
            <div class="message">Товар успішно додано! ID товару: <span id="item-id"><?= $newItemId; ?></span></div>
            <button class="button-copy" onclick="copyToClipboard()">Копіювати ID</button>
        <?php else: ?>
            <div class="message">Помилка при додаванні товару.</div>
        <?php endif; ?>

        <button class="button-back" onclick="window.location.href='add.php?login=<?= $providedLogin; ?>&password=<?= $providedPassword; ?>'">Назад</button>

        <?php
        $stmt->close();
        $conn->close();
        ?>
    </div>

    <script>
        function copyToClipboard() {
            var itemId = document.getElementById('item-id').innerText;
            navigator.clipboard.writeText(itemId).then(function() {
                alert('ID товару скопійовано: ' + itemId);
            }, function(err) {
                alert('Не вдалося скопіювати ID');
            });
        }
    </script>
</body>
</html>
