<?php
// Параметри з'єднання з базою даних
$config = json_decode(file_get_contents('config.json'), true);
$storeName = isset($config['store_name']) ? $config['store_name'] : 'Магазин';
$baseUrl = isset($config['base_url']) ? $config['base_url'] : '';
$servername = isset($config['db_host']) ? $config['db_host'] : 'localhost';
$username = isset($config['db_user']) ? $config['db_user'] : 'root';
$password = isset($config['db_password']) ? $config['db_password'] : '';
$dbname = isset($config['db_name']) ? $config['db_name'] : 'core';
// Створення з'єднання
$conn = new mysqli($servername, $username, $password, $dbname);

// Перевірка з'єднання
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Отримання ID чеку з параметрів URL
$checkId = isset($_GET['id']) ? $_GET['id'] : '';

if (empty($checkId)) {
    die("Чек не знайдено.");
}

// Отримання даних чеку
$sql = "SELECT i.name, i.price, ci.quantity FROM check_items ci JOIN items i ON ci.item_id = i.id WHERE ci.check_id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $checkId);
$stmt->execute();
$result = $stmt->get_result();

$items = [];
$totalAmount = 0;

while ($row = $result->fetch_assoc()) {
    $items[] = $row;
    $totalAmount += $row['price'] * $row['quantity'];
}

$stmt->close();
$conn->close();

// Читання конфігураційного файлу
$config = json_decode(file_get_contents('config.json'), true);
$storeName = isset($config['store_name']) ? $config['store_name'] : 'Магазин';
$baseUrl = isset($config['base_url']) ? $config['base_url'] : '';

// Виведення HTML для чеку
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Чек №<?php echo htmlspecialchars($checkId); ?></title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f4f4f4;
        }
        .invoice {
            width: 100mm; /* Ширина 10 см */
            height: 150mm; /* Висота 15 см */
            max-width: 100%;
            margin: 0 auto; /* Центрування на аркуші */
            padding: 5mm;
            background: #fff;
            border: 1px solid #ddd;
            border-radius: 5px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            font-size: 10px; /* Зменшений шрифт для компактності */
        }
        .invoice h1 {
            font-size: 14px; /* Зменшений розмір заголовка */
            margin: 0 0 5mm;
            text-align: center;
        }
        .invoice table {
            width: 100%;
            border-collapse: collapse;
            margin: 5mm 0;
        }
        .invoice table th, .invoice table td {
            border: 1px solid #ddd;
            padding: 2mm; /* Менші відступи */
            text-align: left;
        }
        .invoice table th {
            background-color: #f4f4f4;
        }
        .invoice .total {
            text-align: right;
            font-weight: bold;
            margin-top: 5mm;
            font-size: 12px; /* Зменшений розмір для підсумкової суми */
        }
        .invoice .footer {
            margin-top: 5mm;
            text-align: center;
            color: #777;
            font-size: 10px; /* Зменшений розмір шрифту для футера */
        }
        .print-btn {
            display: block;
            width: 100%;
            padding: 5mm;
            margin-top: 10mm;
            text-align: center;
            background-color: #007bff;
            color: white;
            border: none;
            border-radius: 5px;
            font-size: 14px;
            cursor: pointer;
        }
        .print-btn:hover {
            background-color: #0056b3;
        }
        .qr-code {
            margin-top: 10mm;
            text-align: center;
        }
        .qr-code img {
            width: 50mm; /* Ширина 5 см */
            height: 50mm; /* Висота 5 см */
        }
        @media print {
            body {
                background: none;
                margin: 0;
                padding: 0;
            }
            .invoice {
                border: none;
                box-shadow: none;
                margin: 0;
                padding: 0;
                width: 100mm; /* Ширина 10 см */
                height: 150mm; /* Висота 15 см */
                page-break-after: avoid;
                page-break-before: avoid;
                page-break-inside: avoid;
            }
            .print-btn {
                display: none;
            }
            @page {
                size: 100mm 150mm; /* Встановлюємо розмір аркуша */
                margin: 0; /* Прибираємо відступи */
            }
        }
    </style>
</head>
<body>
    <div class="invoice">
        <h2><?php echo htmlspecialchars($storeName); ?></h2>
        <h1>Чек №<?php echo htmlspecialchars($checkId); ?></h1>
        <table>
            <thead>
                <tr>
                    <th>Назва товару</th>
                    <th>Кількість</th>
                    <th>Сума</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($items as $item): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($item['name']); ?></td>
                        <td><?php echo htmlspecialchars($item['quantity']); ?></td>
                        <td><?php echo htmlspecialchars(number_format($item['price'] * $item['quantity'], 2)); ?> грн</td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        <div class="total">Всього: <?php echo htmlspecialchars(number_format($totalAmount, 2)); ?> грн</div>
        <div class="footer">
            Дякуємо за покупку!
        </div>
        <div class="qr-code">
            <!-- Місце для QR-коду -->
            <div id="qrcode"></div>
        </div>
        <button class="print-btn" onclick="window.print()">Роздрукувати</button>
    </div>

    <!-- Включення бібліотеки для генерації QR-кодів -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery.qrcode/1.0/jquery.qrcode.min.js"></script>
    <script>
        $(document).ready(function() {
            // Генерація QR-коду
            var baseUrl = "<?php echo htmlspecialchars($baseUrl); ?>";
            var qrData = baseUrl + "/get_check.php?id=<?php echo htmlspecialchars($checkId); ?>";
            $('#qrcode').qrcode({
                text: qrData,
                width: 170, // Ширина QR-коду в пікселях
                height: 170 // Висота QR-коду в пікселях
            });
        });
    </script>
</body>
</html>
