<?php
// Функція для створення таблиць
function createTables($conn) {
    // SQL для створення таблиці 'items'
    $sql_items = "
        CREATE TABLE IF NOT EXISTS items (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(255) NOT NULL,
            price DECIMAL(10, 2) NOT NULL
        );
    ";

    // SQL для створення таблиці 'checks'
    $sql_checks = "
        CREATE TABLE IF NOT EXISTS checks (
            id INT AUTO_INCREMENT PRIMARY KEY,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
        );
    ";

    // SQL для створення таблиці 'check_items'
    $sql_check_items = "
        CREATE TABLE IF NOT EXISTS check_items (
            check_id INT,
            item_id INT,
            quantity INT,
            PRIMARY KEY (check_id, item_id),
            FOREIGN KEY (check_id) REFERENCES checks(id),
            FOREIGN KEY (item_id) REFERENCES items(id)
        );
    ";

    // Виконання запитів для створення таблиць
    if ($conn->query($sql_items) === TRUE) {
        echo "Table 'items' created successfully.<br>";
    } else {
        echo "Error creating table 'items': " . $conn->error . "<br>";
    }

    if ($conn->query($sql_checks) === TRUE) {
        echo "Table 'checks' created successfully.<br>";
    } else {
        echo "Error creating table 'checks': " . $conn->error . "<br>";
    }

    if ($conn->query($sql_check_items) === TRUE) {
        echo "Table 'check_items' created successfully.<br>";
    } else {
        echo "Error creating table 'check_items': " . $conn->error . "<br>";
    }
}

// Перевірка наявності таблиць
function checkAndCreateTables($conn) {
    $tables = ['items', 'checks', 'check_items'];

    foreach ($tables as $table) {
        $result = $conn->query("SHOW TABLES LIKE '$table'");
        if ($result->num_rows === 0) {
            echo "Table '$table' does not exist.<br>";
            createTables($conn); // Запуск скрипту для створення таблиць
            return; // Перервати перевірку після створення таблиць
        }
    }
}

// Перевірка наявності config.json
if (file_exists('config.json')) {
    header('Location: login.php');
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Отримання даних з форми
    $siteUrl = isset($_POST['base_url']) ? $_POST['base_url'] : '';
    $dbHost = isset($_POST['db_host']) ? $_POST['db_host'] : '';
    $dbUser = isset($_POST['db_user']) ? $_POST['db_user'] : '';
    $dbPassword = isset($_POST['db_password']) ? $_POST['db_password'] : '';
    $dbName = isset($_POST['db_name']) ? $_POST['db_name'] : '';
    $adminUser = isset($_POST['admin_user']) ? $_POST['admin_user'] : '';
    $adminPass = isset($_POST['admin_pass']) ? $_POST['admin_pass'] : '';

    // Видалення символу / з кінця URL
    $siteUrl = rtrim($siteUrl, '/');

    // Створення конфігураційного файлу config.json
    $config = [
        'base_url' => $siteUrl,
        'db_host' => $dbHost,
        'db_user' => $dbUser,
        'db_password' => $dbPassword,
        'db_name' => $dbName,
        'login' => $adminUser,
        'password' => $adminPass,
    ];

    // Запис у config.json з опцією JSON_UNESCAPED_SLASHES
    file_put_contents('config.json', json_encode($config, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES));

    // Підключення до бази даних
    $conn = new mysqli($dbHost, $dbUser, $dbPassword, $dbName);

    // Перевірка з'єднання
    if ($conn->connect_error) {
        die("Connection failed: " . $conn->connect_error);
    }

    // Перевірка наявності таблиць та їх створення
    checkAndCreateTables($conn);

    // Закриття з'єднання
    $conn->close();

    // Перенаправлення на login.php
    header('Location: login.php');
    exit;
}
?>

<!DOCTYPE html>
<html lang="uk">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Налаштування</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f2f2f2;
            margin: 0;
            padding: 20px;
        }
        .container {
            max-width: 600px;
            margin: 0 auto;
            background-color: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        .input-group {
            margin-bottom: 15px;
        }
        .input-group label {
            display: block;
            margin-bottom: 5px;
        }
        .input-group input {
            width: 100%;
            padding: 8px;
            box-sizing: border-box;
        }
        .button {
            width: 100%;
            padding: 10px;
            background-color: #4CAF50;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
        .button:hover {
            background-color: #45a049;
        }
    </style>
</head>
<body>
    <div class="container">
        <h2>Налаштування початкових параметрів</h2>
        <form method="POST">
            <div class="input-group">
                <label for="site-url">URL сайту:</label>
                <input type="text" id="site-url" name="base_url" required>
            </div>
            <div class="input-group">
                <label for="db-host">Хост бази даних:</label>
                <input type="text" id="db-host" name="db_host" required>
            </div>
            <div class="input-group">
                <label for="db-user">Користувач бази даних:</label>
                <input type="text" id="db-user" name="db_user" required>
            </div>
            <div class="input-group">
                <label for="db-password">Пароль бази даних:</label>
                <input type="password" id="db-password" name="db_password" required>
            </div>
            <div class="input-group">
                <label for="db-name">Назва бази даних:</label>
                <input type="text" id="db-name" name="db_name" required>
            </div>
            <div class="input-group">
                <label for="admin-user">Користувач адміністратора:</label>
                <input type="text" id="admin-user" name="admin_user" required>
            </div>
            <div class="input-group">
                <label for="admin-pass">Пароль адміністратора:</label>
                <input type="password" id="admin-pass" name="admin_pass" required>
            </div>
            <button type="submit" class="button">Зберегти налаштування</button>
        </form>
    </div>
</body>
</html>
