<?php
$config = json_decode(file_get_contents('config.json'), true);
$storeName = isset($config['store_name']) ? $config['store_name'] : 'Магазин';
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Створення чеку</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            margin: 0;
            padding: 0;
        }
        .container {
            display: flex;
            justify-content: space-between;
            margin: 20px auto;
            max-width: 1200px;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        .items-list, .selected-items {
            width: 48%;
        }
        .center-button {
            display: flex;
            align-items: center;
            justify-content: center;
            width: 4%;
        }
        h1 {
            text-align: center;
            color: #333;
        }
        h2 {
            color: #555;
            text-align: center;
        }
        .item, .selected-item {
            margin-bottom: 15px;
            padding: 10px;
            background-color: #f9f9f9;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        .item label, .selected-item label {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .item input[type="number"] {
            width: 60px;
            padding: 5px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        .item button, .selected-item button {
            background-color: #5bc0de;
            color: white;
            border: none;
            padding: 8px 12px;
            border-radius: 4px;
            cursor: pointer;
        }
        .item button:hover, .selected-item button:hover {
            background-color: #31b0d5;
        }
        .selected-item button {
            background-color: #d9534f;
        }
        .selected-item button:hover {
            background-color: #c9302c;
        }
        .total {
            margin-top: 20px;
            font-weight: bold;
            font-size: 1.2em;
            text-align: right;
        }
        .form-actions {
            text-align: center;
            margin-top: 20px;
        }
        .form-actions input[type="submit"] {
            background-color: #5cb85c;
            color: white;
            border: none;
            padding: 10px 20px;
            font-size: 1em;
            border-radius: 4px;
            cursor: pointer;
        }
        .form-actions input[type="submit"]:hover {
            background-color: #4cae4c;
        }
        .search-container {
            margin-bottom: 20px;
            text-align: center;
        }
        .search-container input[type="text"] {
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            width: 80%;
            max-width: 400px;
        }
    </style>
</head>
<body>
    <h1>Створення чеку</h1>
    <h2><?php echo htmlspecialchars($storeName); ?></h2>
    <form action="create_check.php" method="post">
        <!-- Додаємо приховані поля для логіну і пароля -->
        <input type="hidden" name="login" value="<?php echo htmlspecialchars($_GET['login'] ?? ''); ?>">
        <input type="hidden" name="password" value="<?php echo htmlspecialchars($_GET['password'] ?? ''); ?>">

        <div class="container">
            <div class="items-list">
                <h2>Виберіть товари і введіть кількість</h2>
                <div class="search-container">
                    <input type="text" id="search" placeholder="Пошук товару за id або назвою">
                </div>
                <?php
				
				$servername = isset($config['db_host']) ? $config['db_host'] : 'localhost';
				$username = isset($config['db_user']) ? $config['db_user'] : 'root';
				$password = isset($config['db_password']) ? $config['db_password'] : '';
				$dbname = isset($config['db_name']) ? $config['db_name'] : 'core';
                // Створення з'єднання
                $conn = new mysqli($servername, $username, $password, $dbname);

                // Перевірка з'єднання
                if ($conn->connect_error) {
                    die("Connection failed: " . $conn->connect_error);
                }

                // Отримання списку товарів
                $sql = "SELECT id, name, price FROM items";
                $result = $conn->query($sql);

                $items = [];
                if ($result->num_rows > 0) {
                    while($row = $result->fetch_assoc()) {
                        $items[] = $row;
                    }
                } else {
                    echo "0 results";
                }
                $conn->close();

                foreach ($items as $item): ?>
                    <div class="item" data-id="<?php echo htmlspecialchars($item['id']); ?>" data-name="<?php echo htmlspecialchars($item['name']); ?>">
                        <label>
                            <?php echo htmlspecialchars($item['name']); ?> - <?php echo htmlspecialchars($item['price']); ?> грн
                            <input type="number" class="item-quantity" min="1" placeholder="Кількість" data-id="<?php echo htmlspecialchars($item['id']); ?>" data-price="<?php echo htmlspecialchars($item['price']); ?>" />
                        </label>
                    </div>
                <?php endforeach; ?>
            </div>

            <div class="center-button">
                <button type="button" id="add-all-btn">+</button>
            </div>

            <div class="selected-items">
                <h2>Вибрані товари</h2>
                <div id="selected-items-list">
                    <!-- Додані товари будуть тут -->
                </div>
                <div class="total">
                    Сума: <span id="total-amount">0</span> грн
                </div>
            </div>
        </div>

        <div class="form-actions">
            <input type="submit" value="Створити чек">
        </div>
    </form>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const selectedItemsList = document.getElementById('selected-items-list');
            const totalAmountElem = document.getElementById('total-amount');
            const addAllBtn = document.getElementById('add-all-btn');
            const searchInput = document.getElementById('search');

            function updateSelectedItems() {
                selectedItemsList.innerHTML = '';
                let totalAmount = 0;

                document.querySelectorAll('.item-quantity').forEach(input => {
                    const quantity = parseInt(input.value);
                    const price = parseFloat(input.dataset.price);
                    const itemId = input.dataset.id;
                    if (quantity > 0) {
                        const itemDiv = document.createElement('div');
                        itemDiv.classList.add('selected-item');
                        itemDiv.innerHTML = `
                            <label>
                                ${input.parentElement.textContent.trim()} - ${quantity} шт
                                <input type="hidden" name="items[]" value="${itemId}">
                                <input type="hidden" name="quantity_${itemId}" value="${quantity}">
                                <button type="button" class="remove-btn">-</button>
                            </label>
                        `;
                        selectedItemsList.appendChild(itemDiv);
                        totalAmount += quantity * price;
                    }
                });

                totalAmountElem.textContent = totalAmount.toFixed(2);
            }

            // Додаємо всі товари в список
            addAllBtn.addEventListener('click', () => {
                updateSelectedItems();
            });

            // Видаляємо товар зі списку
            selectedItemsList.addEventListener('click', function(event) {
                if (event.target.classList.contains('remove-btn')) {
                    const itemId = event.target.previousElementSibling.previousElementSibling.value;
                    document.querySelector(`.item-quantity[data-id="${itemId}"]`).value = '';
                    event.target.closest('.selected-item').remove();
                    updateSelectedItems();
                }
            });

            // Фільтрація товарів за пошуковим запитом
            searchInput.addEventListener('input', function() {
                const searchTerm = searchInput.value.toLowerCase();
                document.querySelectorAll('.item').forEach(item => {
                    const id = item.getAttribute('data-id').toLowerCase();
                    const name = item.getAttribute('data-name').toLowerCase();
                    if (id.includes(searchTerm) || name.includes(searchTerm)) {
                        item.style.display = '';
                    } else {
                        item.style.display = 'none';
                    }
                });
            });
        });
    </script>
</body>
</html>
